/*
 * \brief  TPM2 session callbacks to enable policy
 *         sessions for tpm2-openssl
 * \author Stefan Thöni
 * \date   2023-11-23
 */

#pragma once

#include <tss2/tss2_esys.h>

#ifdef __cplusplus
extern "C" {
#endif
	typedef TSS2_RC (*start_session_fn) (ESYS_CONTEXT *esys_context, ESYS_TR *session_handle);
	typedef TSS2_RC (*set_policy_fn) (ESYS_CONTEXT *esys_context);
	typedef ESYS_TR (*get_session_handle_fn) (ESYS_CONTEXT *esys_context);
	typedef TSS2_RC (*get_session_auth_fn) (ESYS_CONTEXT *esys_context, TPM2B_DIGEST** auth);

	void set_create_session_callback(start_session_fn cb);
	void set_set_policy_callback(set_policy_fn cb);
	void set_get_session_handle_callback(get_session_handle_fn cb);
	void set_get_session_auth_callback(get_session_auth_fn cb);

	TSS2_RC call_create_session_callback(ESYS_CONTEXT *esys_context, ESYS_TR *session_handle);
	TSS2_RC call_set_policy_callback(ESYS_CONTEXT *esys_context);
	ESYS_TR call_get_session_handle_callback(ESYS_CONTEXT *esys_context);
	TSS2_RC call_get_session_auth_callback(ESYS_CONTEXT *esys_context, TPM2B_DIGEST** auth);
#ifdef __cplusplus
}
#endif
